@@ -1,10 +1,14 @@
 from typing import Optional
 
-# We use the longers paths here as PyCharm will suggest imports from here for other classes
+# We use the longer paths here as PyCharm will suggest imports from here for other classes
 from piate.api import client as client_mod, session as sessions, credentials, resources
 
 
 class MissingAuthentication(Exception):
+    """
+    Raise when no authentication information is provided
+    """
+
     def __init__(self):
         super().__init__(
             "Either a 'session' object or a 'username' and 'api_key' must be provided."
@@ -16,6 +20,11 @@ def client(
     api_key: Optional[str] = None,
     session: Optional[sessions.Session] = None,
 ):
+    """
+    Library entrypoint. If `username` and `api_key` (conflicts with `session`) are supplied they are used to
+    authenticate against the API. If `session` (conflicts with `username` and `api_key`) is provided, it is used in
+    place of `username` and `api_key`.
+    """
     has_login = (username is not None) and (api_key is not None)
     has_session = session is None
 
