@@ -1,11 +1,12 @@
 from dataclasses import dataclass
 from typing import List, Dict, NewType
 
-from dataclasses_json import dataclass_json
+from dataclasses_json import dataclass_json, Undefined
 
-from piate.api.authentication.base import (
+from piate.api.authentication import (
     AuthenticationBase,
     RefreshToken,
+    ExpirationBase,
 )
 from piate.api.version import APIVersion
 
@@ -15,11 +16,13 @@ AuthToken = NewType("AuthToken", str)
 @dataclass_json(undefined=Undefined.RAISE)
 @dataclass
 class TokenResponse:
+    """Response from the Authentication API"""
+
     token_type: str
     tokens: List[AuthToken]
     refresh_token: RefreshToken
-    permission_name_by_id: Dict[str:str]
-    role_group_name_by_id: Dict[str:str]
+    permission_name_by_id: Dict[str, str]
+    role_group_name_by_id: Dict[str, str]
     expiration: ExpirationBase
 
 
